aboutsummaryrefslogtreecommitdiff
path: root/scripts/vim-patch.sh
diff options
context:
space:
mode:
authorJustin M. Keyes <justinkz@gmail.com>2018-10-05 09:12:52 +0200
committerJustin M. Keyes <justinkz@gmail.com>2018-10-05 09:51:38 +0200
commitc05982cf357e3019b3103b2ce8954fe9bae4652f (patch)
tree9bc2ddc00f96509e67a4056d42cef8463d40a8b2 /scripts/vim-patch.sh
parentc1c5c4f8e498af77fc45f5c07068412af3dc1764 (diff)
downloadrneovim-c05982cf357e3019b3103b2ce8954fe9bae4652f.tar.gz
rneovim-c05982cf357e3019b3103b2ce8954fe9bae4652f.tar.bz2
rneovim-c05982cf357e3019b3103b2ce8954fe9bae4652f.zip
vim-patch.sh: Skip Vim screen-dump files
Diffstat (limited to 'scripts/vim-patch.sh')
-rwxr-xr-xscripts/vim-patch.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/vim-patch.sh b/scripts/vim-patch.sh
index 2d7cbf4552..de0d040b47 100755
--- a/scripts/vim-patch.sh
+++ b/scripts/vim-patch.sh
@@ -156,8 +156,8 @@ preprocess_patch() {
# Remove "Last change ..." changes in doc files.
2>/dev/null $nvim --cmd 'set dir=/tmp' +'%s/^@@.*\n.*For Vim version.*Last change.*\n.*For Vim version.*Last change.*//' +w +q "$file"
- # Remove some testdir/Make_*.mak files
- local na_src_testdir='Make_amiga.mak\|Make_dos.mak\|Make_ming.mak\|Make_vms.mms'
+ # Remove screen dumps, testdir/Make_*.mak files
+ local na_src_testdir='Make_amiga.mak\|Make_dos.mak\|Make_ming.mak\|Make_vms.mms\|dumps/.*.dump'
2>/dev/null $nvim --cmd 'set dir=/tmp' +'g@^diff --git a/src/testdir/\<\%('${na_src_testdir}'\)\>@norm! d/\v(^diff)|%$ ' +w +q "$file"
# Remove version.c #7555